#ifndef __FT800_DEFS_H__
#define __FT800_DEFS_H__

/* Transaction types */
#define FT800_MEM_READ          (0x00)
#define FT800_MEM_WRITE         (0x80)
#define FT800_CMD               (0x40)

/* Host commands */
#define FT800_ACTIVE            (0x00)
#define FT800_STANDBY           (0x01)
#define FT800_SLEEP             (0x02)
#define FT800_PWRDOWN           (0x10)
#define FT800_CLKEXT            (0x04)
#define FT800_CLK48M            (0x22)
#define FT800_CLK36M            (0x21)
#define FT800_CORERST           (0x28)

/* Memory map */
#define FT800_MAIN_RAM          (0)
#define FT800_CHIP_ID           (0xC0000)
#define FT800_VERSION_ID        (0xC0002)
#define FT800_ROM_FONT          (0xBB23C)
#define FT800_ROMT_FONT_ADDR    (0xFFFFC)
#define FT800_RAM_DL            (0x100000)
#define FT800_RAM_PAL           (0x102000)
#define FT800_RAM_CMD           (0x108000)

/* Video registers */
#define FT800_REG_ID                (0x102400)
#define FT800_REG_FRAMES            (0x102404)
#define FT800_REG_CLOCK             (0x102408)
#define FT800_REG_FREQUENCY         (0x10240C)
#define FT800_REG_RENDER_MODE       (0x102410)
#define FT800_REG_SNAPY             (0x102414)
#define FT800_REG_SNAPSHOT          (0x102418)
#define FT800_REG_CPURESET          (0x10241C)
#define FT800_REG_TAP_CRC           (0x102420)
#define FT800_REG_TAP_MASK          (0x102424)
#define FT800_REG_HCYCLE            (0x102428)
#define FT800_REG_HOFFSET           (0x10242C)
#define FT800_REG_HSIZE             (0x102430)
#define FT800_REG_HSYNC0            (0x102434)
#define FT800_REG_HSYNC1            (0x102438)
#define FT800_REG_VCYCLE            (0x10243C)
#define FT800_REG_VOFFSET           (0x102440)
#define FT800_REG_VSIZE             (0x102444)
#define FT800_REG_VSYNC0            (0x102448)
#define FT800_REG_VSYNC1            (0x10244C)
#define FT800_REG_DLSWAP            (0x102450)
#define FT800_REG_ROTATE            (0x102454)
#define FT800_REG_OUTBITS           (0x102458)
#define FT800_REG_DITHER            (0x10245C)
#define FT800_REG_SWIZZLE           (0x102460)
#define FT800_REG_CSPREAD           (0x102464)
#define FT800_REG_PCLK_POL          (0x102468)
#define FT800_REG_PCLK              (0x10246C)
#define FT800_REG_TAG_X             (0x102470)
#define FT800_REG_TAG_Y             (0x102474)
#define FT800_REG_TAG               (0x102478)

/* GPIO registers */
#define FT800_REG_GPIO_DIR          (0x10248C)
#define FT800_REG_GPIO              (0x102490)

/* Interrupts registers */
#define FT800_REG_INT_FLAGS         (0x102498)
#define FT800_REG_INT_EN            (0x10249C)
#define FT800_REG_INT_MASK          (0x1024A0)

/* Sound registers */
#define FT800_REG_VOL_PB            (0x10247C)
#define FT800_REG_VOL_SOUND         (0x102480)
#define FT800_REG_SOUND             (0x102484)
#define FT800_REG_PLAY              (0x102488)
#define FT800_REG_PLAYBACK_START    (0x1024A4)
#define FT800_REG_PLAYBACK_LENGTH   (0x1024A8)
#define FT800_REG_PLAYBACK_READPTR  (0x1024AC)
#define FT800_REG_PLAYBACK_FREQ     (0x1024B0)
#define FT800_REG_PLAYBACK_FORMAT   (0x1024B4)
#define FT800_REG_PLAYBACK_LOOP     (0x1024B8)
#define FT800_REG_PLAYBACK_PLAY     (0x1024BC)

/* Backlight registers */
#define FT800_REG_PWM_HZ            (0x1024C0)
#define FT800_REG_PWM_DUTY          (0x1024C4)

/* Command registers */
#define FT800_REG_MACRO0            (0x1024C8)
#define FT800_REG_MACRO1            (0x1024CC)
#define FT800_REG_CMD_READ          (0x1024E4)
#define FT800_REG_CMD_WRITE         (0x1024E8)
#define FT800_REG_CMD_DL            (0x1024EC)

/* Touch screen registers */
#define FT800_REG_TOUCH_MODE            (0x1024F0)
#define FT800_REG_TOUCH_ADC_MODE        (0x1024F4)
#define FT800_REG_TOUCH_CHARGE          (0x1024F8)
#define FT800_REG_TOUCH_SETTLE          (0x1024FC)
#define FT800_REG_TOUCH_OVERSAMPLE      (0x102500)
#define FT800_REG_TOUCH_RZTHRESHOLD     (0x102504)
#define FT800_REG_TOUCH_RAW_XY          (0x102508)
#define FT800_REG_TOUCH_RZ              (0x10250C)
#define FT800_REG_TOUCH_SCREEN_XY       (0x102510)
#define FT800_REG_TOUCH_TAG_XY          (0x102514)
#define FT800_REG_TOUCH_TAG             (0x102518)
#define FT800_REG_TOUCH_TRANSFORM_A     (0x10251C)
#define FT800_REG_TOUCH_TRANSFORM_B     (0x102520)
#define FT800_REG_TOUCH_TRANSFORM_C     (0x102524)
#define FT800_REG_TOUCH_TRANSFORM_D     (0x102528)
#define FT800_REG_TOUCH_TRANSFORM_E     (0x10252C)
#define FT800_REG_TOUCH_TRANSFORM_F     (0x102530)
#define FT800_REG_TOUCH_DIRECT_XY       (0x102574)
#define FT800_REG_TOUCH_DIRECT_Z1Z2     (0x102578)

#define FT800_REG_TRACKER               (0x109000)

/* Display list opcodes */
#define FT800_ALPHA_FUNC                (0x09 << 24)
#define FT800_BEGIN                     (0x1F << 24)
#define FT800_BITMAP_HANDLE             (0x05 << 24)
#define FT800_BITMAP_LAYOUT             (0x07 << 24)
#define FT800_BITMAP_SIZE               (0x08 << 24)
#define FT800_BITMAP_SOURCE             (0x01 << 24)
#define FT800_BITMAP_TRANSFORM_A        (0x15 << 24)
#define FT800_BITMAP_TRANSFORM_B        (0x16 << 24)
#define FT800_BITMAP_TRANSFORM_C        (0x17 << 24)
#define FT800_BITMAP_TRANSFORM_D        (0x18 << 24)
#define FT800_BITMAP_TRANSFORM_E        (0x19 << 24)
#define FT800_BITMAP_TRANSFORM_F        (0x1F << 24)
#define FT800_BLEND_FUNC                (0x0B << 24)
#define FT800_CALL                      (0x1D << 24)
#define FT800_CELL                      (0x06 << 24)
#define FT800_CLEAR                     (0x26 << 24)
#define FT800_CLEAR_COLOR_A             (0x0F << 24)
#define FT800_CLEAR_COLOR_RGB           (0x02 << 24)
#define FT800_CLEAR_STENCIL             (0x11 << 24)
#define FT800_CLEAR_TAG                 (0x06 << 24)
#define FT800_COLOR_A                   (0x10 << 24)
#define FT800_COLOR_MASK                (0x20 << 24)
#define FT800_COLOR_RGB                 (0x04 << 24)
#define FT800_DISPLAY                   (0)
#define FT800_END                       (0x21 << 24)
#define FT800_JUMP                      (0x1E << 24)
#define FT800_LINE_WIDTH                (0x06 << 24)
#define FT800_MACRO                     (0x25 << 24)
#define FT800_POINT_SIZE                (0x0D << 24)
#define FT800_RESTORE_CONTEXT           (0x23 << 24)
#define FT800_RETURN                    (0x24 << 24)
#define FT800_SAVE_CONTEXT              (0x22 << 24)
#define FT800_SCISSOR_SIZE              (0x1C << 24)
#define FT800_SCISSOR_XY                (0x1B << 24)
#define FT800_STENCIL_FUNC              (0x0A << 24)
#define FT800_STENCIL_MASK              (0x13 << 24)
#define FT800_STENCIL_OP                (0x0C << 24)
#define FT800_TAG                       (0x03 << 24)
#define FT800_TAG_MASK                  (0x14 << 24)
#define FT800_VERTEX2F                  (0x01 << 30)
#define FT800_VERTEX2II                 (0x02 << 30)

/* Coprocessor opcodes */
#define FT800_APPEND                    (0xFFFFFF02)
#define FT800_BGCOLOR                   (0xFFFFFF09)
#define FT800_BUTTON                    (0xFFFFFF0D)
#define FT800_CALIBRATE                 (0xFFFFFF15)
#define FT800_CLOCK                     (0xFFFFFF14)
#define FT800_COLDSTART                 (0xFFFFFF32)
#define FT800_DIAL                      (0xFFFFFF2D)
#define FT800_DLSTART                   (0xFFFFFF00)
#define FT800_FGCOLOR                   (0xFFFFFF0A)
#define FT800_GAUGE                     (0xFFFFFF13)
#define FT800_GETMATRIX                 (0xFFFFFF33)
#define FT800_GETPTR                    (0xFFFFFF23)
#define FT800_GRADCOLOR                 (0xFFFFFF34)
#define FT800_GRADIENT                  (0xFFFFFF0B)
#define FT800_INFLATE                   (0xFFFFFF22)
#define FT800_INTERRUPT                 (0xFFFFFF02)
#define FT800_KEYS                      (0xFFFFFF0E)
#define FT800_LOADIDENTITY              (0xFFFFFF26)
#define FT800_LOADIMAGE                 (0xFFFFFF24)
#define FT800_LOGO                      (0xFFFFFF31)
#define FT800_MEMCPY                    (0xFFFFFF1D)
#define FT800_MEMCRC                    (0xFFFFFF18)
#define FT800_MEMSET                    (0xFFFFFF1B)
#define FT800_MEMWRITE                  (0xFFFFFF1A)
#define FT800_MEMZERO                   (0xFFFFFF1C)
#define FT800_NUMBER                    (0xFFFFFF2E)
#define FT800_PROGRESS                  (0xFFFFFF0F)
#define FT800_REGREAD                   (0xFFFFFF19)
#define FT800_ROTATE                    (0xFFFFFF29)
#define FT800_SCALE                     (0xFFFFFF28)
#define FT800_SCREENSAVER               (0xFFFFFF2F)
#define FT800_SCROLLBAR                 (0xFFFFFF11)
#define FT800_SETMATRIX                 (0xFFFFFF2A)
#define FT800_SKETCH                    (0xFFFFFF30)
#define FT800_SLIDER                    (0xFFFFFF10)
#define FT800_SNAPSHOT                  (0xFFFFFF1F)
#define FT800_SPINNER                   (0xFFFFFF16)
#define FT800_STOP                      (0xFFFFFF17)
#define FT800_SWAP                      (0xFFFFFF01)
#define FT800_TEXT                      (0xFFFFFF0C)
#define FT800_TOGGLE                    (0xFFFFFF12)
#define FT800_TRACK                     (0xFFFFFF2C)
#define FT800_TRANSLATE                 (0xFFFFFF27)


/* Value of FT800_REG_ID */
#define FT800_DEVICE_ID         (0x7C)

/* Value for FT800_REG_DLSWAP */
#define FT800_SWAP_FRAME        (2)

/* Functions */
#define FT800_FUNC_NEVER        (0)
#define FT800_FUNC_LESS         (1)
#define FT800_FUNC_LEQUAL       (2)
#define FT800_FUNC_GREATER      (3)
#define FT800_FUNC_GEQUAL       (4)
#define FT800_FUNC_EQUAL        (5)
#define FT800_FUNC_NOTEQUAL     (6)
#define FT800_FUNC_ALWAYS       (7)

/* Primitives */
#define FT800_BITMAPS           (1)
#define FT800_POINTS            (2)
#define FT800_LINES             (3)
#define FT800_LINE_STRIP        (4)
#define FT800_EDGE_STRIP_R      (5)
#define FT800_EDGE_STRIP_L      (6)
#define FT800_EDGE_STRIP_A      (7)
#define FT800_EDGE_STRIP_B      (8)
#define FT800_RECTS             (9)

/* Formats */
#define FT800_ARGB1555          (0)
#define FT800_L1                (1)
#define FT800_L4                (2)
#define FT800_L8                (3)
#define FT800_RGB332            (4)
#define FT800_ARGB2             (5)
#define FT800_ARGB4             (6)
#define FT800_RGB565            (7)
#define FT800_PALETTED          (8)
#define FT800_TEXT8X8           (9)
#define FT800_TEXTVGA           (10)
#define FT800_BARGRAPH          (11)

/* Filters */
#define FT800_NEAREST           (0)
#define FT800_BILINEAR          (1)

/* Wrap modes */
#define FT800_BORDER            (0)
#define FT800_REPEAT            (1)

/* Blend functions */
#define FT800_BLEND_ZERO                    (0)
#define FT800_BLEND_ONE                     (1)
#define FT800_BLEND_SRC_ALPHA               (2)
#define FT800_BLEND_DST_ALPHA               (3)
#define FT800_BLEND_ONE_MINUS_SRC_ALPHA     (4)
#define FT800_BLEND_ONE_MINUS_DST_ALPHA     (5)

/* Options */
#define FT800_OPT_3D                        (0)
#define FT800_OPT_RGB565                    (0)
#define FT800_OPT_MONO                      (1)
#define FT800_OPT_NODL                      (2)
#define FT800_OPT_FLAT                      (256)
#define FT800_OPT_SIGNED                    (256)
#define FT800_OPT_CENTERX                   (512)
#define FT800_OPT_CENTERY                   (1024)
#define FT800_OPT_CENTER                    (1536)
#define FT800_OPT_RIGHTX                    (2048)
#define FT800_OPT_NOBACK                    (4096)
#define FT800_OPT_NOTICKS                   (8192)
#define FT800_OPT_NOHM                      (16384)
#define FT800_OPT_NOPOINTER                 (16384)
#define FT800_OPT_NOSECS                    (32768)
#define FT800_OPT_NOHANDS                   (49152)

/* Interrupts */
#define FT800_INT_SWAP                  (0x01)
#define FT800_INT_TOUCH                 (0x02)
#define FT800_INT_TAG                   (0x04)
#define FT800_INT_SOUND                 (0x08)
#define FT800_INT_PLAYBACK              (0x10)
#define FT800_INT_CMD_FIFO_EMPTY        (0x20)
#define FT800_INT_CMD_FIFO_FLAG         (0x40)
#define FT800_INT_CONVCOMPLETE          (0x80)

/* Touch controller modes */
#define FT800_TOUCH_MODE_OFF            (0)
#define FT800_TOUCH_MODE_ONE_SHOT       (0x01)
#define FT800_TOUCH_MODE_FRAME_SYNC     (0x02)
#define FT800_TOUCH_MODE_CONTINUOUS     (0x03)

#endif

